@@ -12,7 +12,7 @@ run_test()
 
 run_device_tests()
 {
-	if [ -d /usr/share/fwupd/device-tests ]; then
+	if [ -n "$CI_NETWORK" ] && [ -d /usr/share/fwupd/device-tests ]; then
 		# grab device tests from the CDN to avoid incrementing the download counter
 		export FWUPD_DEVICE_TESTS_BASE_URI=http://cdn.fwupd.org/downloads
 		for f in `grep --files-with-matches -r emulation-url /usr/share/fwupd/device-tests`; do
@@ -38,7 +38,8 @@ run_test uefi-dbx-self-test
 run_test synaptics-prometheus-self-test
 run_test dfu-self-test
 run_test mtd-self-test
-run_device_tests
+run_test vli-self-test
+# run_device_tests
 
 # success!
 exit 0
